'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

exports.installTractorLocally = installTractorLocally;

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _child_process = require('child_process');

var _child_process2 = _interopRequireDefault(_child_process);

var _tractorLogger = require('tractor-logger');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Constants;
var INSTALL_DEPENDENCIES_COMMAND = 'npm install --save-dev tractor@latest';
var LOCAL_TRACTOR_VERSION_COMMAND = 'npm --json list tractor';
var REMOTE_TRACTOR_VERSIONS_COMMAND = 'npm --json info tractor versions';

// Dependencies:
function installTractorLocally() {
    return _bluebird2.default.all([getInstalledTractorVersion(), getRemoteTractorVersion()]).spread(function (installed, remote) {
        if (installed !== remote) {
            return installTractor();
        }
    });
}

function getInstalledTractorVersion() {
    (0, _tractorLogger.info)('Checking local "tractor" version...');
    return _child_process2.default.execAsync(LOCAL_TRACTOR_VERSION_COMMAND).then(function (local) {
        var version = JSON.parse(local).dependencies.tractor.version;

        (0, _tractorLogger.info)('Local version of "tractor" is: ' + version);
        return version;
    }).catch(function () {
        (0, _tractorLogger.info)('"tractor" is not installed.');
    });
}

function getRemoteTractorVersion() {
    (0, _tractorLogger.info)('Checking remote "tractor" version...');
    return _child_process2.default.execAsync(REMOTE_TRACTOR_VERSIONS_COMMAND).then(function (versions) {
        var _JSON$parse$reverse = JSON.parse(versions).reverse(),
            _JSON$parse$reverse2 = _slicedToArray(_JSON$parse$reverse, 1),
            latest = _JSON$parse$reverse2[0];

        (0, _tractorLogger.info)('Latest remote version of "tractor" is: ' + latest);
        return latest;
    });
}

function installTractor() {
    (0, _tractorLogger.info)('Installing "tractor"...');
    return _child_process2.default.execAsync(INSTALL_DEPENDENCIES_COMMAND).then(function () {
        return (0, _tractorLogger.info)('Installed "tractor".');
    }).catch(function () {
        return (0, _tractorLogger.error)('Couldn\'t install "tractor". Either run "tractor init" again, or install it manually by running "npm install tractor@latest --save-dev"');
    });
}